diff -r bb30d01684af rust/rhgitaly/src/repository.rs
--- a/rust/rhgitaly/src/repository.rs	Fri Jul 05 12:06:10 2024 +0200
+++ b/rust/rhgitaly/src/repository.rs	Fri Jul 05 16:41:34 2024 +0200
@@ -5,6 +5,7 @@
 // SPDX-License-Identifier: GPL-2.0-or-later
 use std::ffi::{OsStr, OsString};
 use std::fmt;
+use std::io::ErrorKind;
 use std::marker::Send;
 use std::os::unix::ffi::OsStringExt;
 use std::path::{Path, PathBuf};
@@ -160,17 +161,21 @@
     condition: impl FnMut(&[u8]) -> bool,
 ) -> Result<bool, Status> {
     let path = vfs.join("requires"); // TODO const
-    Ok(fs::read(&path)
-        .await
-        .map_err(|e| {
-            Status::internal(format!(
-                "Could not open requirements at {}: {}",
-                path.display(),
-                e
-            ))
-        })?
-        .split(|b| *b == b'\n')
-        .any(condition))
+    let reqs = match fs::read(&path).await {
+        Ok(bytes) => bytes,
+        Err(e) => {
+            if e.kind() == ErrorKind::NotFound {
+                return Ok(false);
+            } else {
+                return Err(Status::internal(format!(
+                    "Could not open requirements at {}: {}",
+                    path.display(),
+                    e
+                )));
+            }
+        }
+    };
+    Ok(reqs.split(|b| *b == b'\n').any(condition))
 }
 
 /// Return `Status::Unimplemented` if the repo has the `largefiles` requirement.
@@ -185,6 +190,14 @@
         // TODO const
         return Err(Status::unimplemented("largefiles repo requirement"));
     };
+    // The requires file can be in the working dir vfs (probably older
+    // repositories, that don't have any .hg/store/requires)
+    if let Some(root_vfs) = store_vfs.parent() {
+        if has_requirement_with(root_vfs, |req| req == b"largefiles").await? {
+            // TODO const
+            return Err(Status::unimplemented("largefiles repo requirement"));
+        }
+    }
     Ok(())
 }
 
